@@ -39,6 +39,7 @@ class R3sponse(object):
 		response = self.default_response()
 		response["success"] = True
 		response["message"] = message
+		response["error"] = None
 		for key, value in variables.items():
 			response[key] = value
 		r3sponse.log(message=response["message"], log_level=log_level, save=save)
@@ -55,6 +56,8 @@ class R3sponse(object):
 		django=False,
 	):
 		response = self.default_response()
+		response["success"] = False
+		response["message"] = None
 		response["error"] = error
 		r3sponse.log(error=response["error"], log_level=log_level, save=save)
 		if django: response = JsonResponse(response)
@@ -209,6 +212,8 @@ class ResponseObject(object):
 		return vars(self).items()
 	def keys(self):
 		return list(vars(self).keys())
+	def values(self):
+		return list(vars(self).values())
 	def dict(self):
 		dictionary = {}
 		for key, value in self.items():
